## sambaToken.py - data structure for system-config-samba
## Copyright (C) 2002, 2003 Red Hat, Inc.
## Copyright (C) 2002, 2003 Brent Fox <bfox@redhat.com>

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

from sambaDefaults import global_keys
from sambaDefaults import section_keys
from sambaDefaults import synonym_dict
from sambaDefaults import inverted_synonym_dict
import string

class SambaToken:
    SAMBA_TOKEN_STRING = 1
    SAMBA_TOKEN_SECTION_HEADER = 2
    SAMBA_TOKEN_KEYVAL = 3
    SAMBA_TOKEN_BLANKLINE = 4
    
    def __init__(self, type, value, parent = None, comment = None):
#        print "init", type, parent, value, comment

        if type == SambaToken.SAMBA_TOKEN_KEYVAL:
            if value[0] not in section_keys.keys() and value[0] not in global_keys.keys():
                raise AttributeError, value

            self.keyname = value[0]
            self.keyval = value[1]

            #We need a sane way of handling samba keyname synonyms.  Otherwise we could have conflicting tags
            for key in synonym_dict.keys():
                if self.keyname in synonym_dict[key]:
                    #We've found a synonym, so convert it to the real keyname
                    self.keyname = key

            #Now we need to check for the insane concept of inverted keynames.
            for key in inverted_synonym_dict.keys():
                if self.keyname in inverted_synonym_dict[key]:
                    #We've found a synonym, so convert it to the real keyname
                    self.keyname = key

                    #Now we need to invert the value.  AFAIK, the inverted case is only for yes/no values
                    if string.lower(self.keyval) == "no":
                        self.keyval = "yes"
                    elif string.lower(self.keyval) == "yes":
                        self.keyval = "no"

        self.type = type
        self.value = value
        self.comment = comment
        self.parent = parent
        
    def getData(self):
        if self.type == SambaToken.SAMBA_TOKEN_STRING:
            return ("%s\n" % self.value)
        elif self.type == SambaToken.SAMBA_TOKEN_SECTION_HEADER:
            return ("%s\n" % self.value)
        elif self.type == SambaToken.SAMBA_TOKEN_KEYVAL:
            if self.keyname in global_keys.keys():
                default = global_keys[self.keyname]
                if default:
                    default = string.lower(str(default))

                if default == string.lower(str(self.keyval)):
                    return 
            elif self.keyname in section_keys.keys():
                default = section_keys[self.keyname]
                if default:
                    default = string.lower(str(default))
                if default == None and self.keyval == None:
                    return
                elif default == string.lower(str(self.keyval)):
                    return 

            if self.comment:
                return ("\t%s = %s \t#%s\n" % (self.keyname, self.keyval, self.comment))
            else:
                return ("\t%s = %s\n" % (self.keyname, self.keyval))
            
        elif self.type == SambaToken.SAMBA_TOKEN_BLANKLINE:
            return "\n"

    def getParent(self):
        return self.parent
